==> abi-0.7.9.tar.gz: abi-0.7.9/src/wp/ap/xp/ap_Menu_LabelSet_cs-CZ.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Czech translation provided by Zbynek Miksa <xmiksa@informatics.muni.cz>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(cs,CZ,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,			"&Soubor",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Nov", 			"Vytvoit nov dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&Otevt",			"Otevt existujc dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Zavt", 			"Zavt dokument")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Uloit", 			"Uloit dokument")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Uloit &jako", 		"Uloit dokument pod jinm jmnem")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,		"Nasta&ven tisku ",		"Zmnit nastaven tisku")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Tisk",			"Vytisknout cel dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Konec", 			"Zavt vechny okna a ukonit aplikaci")

	MenuLabel(AP_MENU_ID_EDIT,			"pr&avy",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Zpt",			"Zpt editace")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"V&ped",			"Redo previously undone editing")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Vyjmout",			"Pesunout oznaen oblasti do schrnky")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Koprovat",			"Zkoprovat oznaen oblasti do schrnky")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"V&loit",			"Vloit obsah schrnky")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"Od&stranit",			"Smazat oznaenou oblast")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,		"Vybr&at ve",			"Vybrat cel dokument")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Najt",			"Nalzt urit text")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"Nah&radit",			"Nahradit urit text jinm")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&Skok na",			"Pesun kurzoru na poadovanou stranu")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Zobrazit",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Nstroje",		NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standartn",			"Zobrazit nebo skrt standartn panel nstroj")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,		"&Formt",			"Zobrazit nebo skrt panel nstroj pro formtovn")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Pravtko",			"Zobrazit nebo skrt pravtko")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,		"&Stavov dek",		"Zobrazit nebo skrt stavov dek")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Zobrazovat Para&graphs",	"Zobrazovat netisknuteln znaky")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Zhlav a zpat",		"Editovn textu v zhlav a zpat")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Lupa",			"Zmenen nebo zvten zobrazen dokumentu")

	MenuLabel(AP_MENU_ID_INSERT,			"&Vloit",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Konec",			"Vloit konec strnky, sloupce nebo odstavce")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"s&la strnek",		"Vloit automatick slovn")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,		"Datum a as",			"Vloit as a/nebo datum")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Pole",			"Vloit potan pole")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Symbol",			"Vloit symbol nebo jin speciln znak")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"&Obrzek",			"Vloit obrzek ze souboru")

	MenuLabel(AP_MENU_ID_FORMAT,			"F&ormt",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Font",			"Zmnit font vybranho textu")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Odstavec",			"Zmnit formt vybranho odstavce")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Odrky a slovn",		"Pidat nebo zmnit odrky a slovn vybranho odstavce")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Okraje a stnovn",		"Pidat okraje a stnovn vybranmu textu")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Sloupce",			"Zmnit poet sloupc")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"St&yl",			"Definovat nebo aplikovat styl na vybran")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabultory",			"Nastaven tabultor")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Tun",			"Nastaven tunho psma pro vybranou oblast")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kurzva",			"Nastaven kurzivy pro vybranou oblast")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Potren",			"Podtren psma ve vybran oblasti")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"Pek&rknut",			"Pekrknut psma ve vybran oblasti")

	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"Pravopi&s",			"Zkontrolovat pravopis")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Monosti",			"Nastaven monost")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Umstn",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vlevo",			"Zarovnn odstavce vlevo")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Uprosted",			"Zarovnn odstavce uprosted")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"V&pravo",			"Zarovnn odstavce vpravo")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Do bloku",			"Zarovnn odstavce do bloku")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Okno",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nov Okno",			"Otevt nov okno")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Vce oken",			"Zobrazit seznam vech oken")

	MenuLabel(AP_MENU_ID_HELP,			"Npo&vda",			NULL)
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&O programu %s",		"Zobrazit informace o programu, slo verze a copyright")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorovat ve", 		"Ignorovat vechny vskyty tohoto slova v dokumentu")
	MenuLabel(AP_MENU_ID_SPELL_ADD,		"&Pidat", 			"Pidat toto slovo do uivatelskho slovnku")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_Menu_LabelSet_cs-CZ.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Czech translation provided by Zbynek Miksa <xmiksa@informatics.muni.cz>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(cs,CZ,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,			"&Soubor",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Nov", 			"Vytvoit nov dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&Otevt",			"Otevt existujc dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Zavt", 			"Zavt dokument")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Uloit", 			"Uloit dokument")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Uloit &jako", 		"Uloit dokument pod jinm jmnem")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,		"Nasta&ven tisku ",		"Zmnit nastaven tisku")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Tisk",			"Vytisknout cel dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Otevt tento dokument")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Konec", 			"Zavt vechny okna a ukonit aplikaci")

	MenuLabel(AP_MENU_ID_EDIT,			"pr&avy",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Zpt",			"Zpt editace")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"V&ped",			"Redo previously undone editing")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Vyjmout",			"Pesunout oznaen oblasti do schrnky")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Koprovat",			"Zkoprovat oznaen oblasti do schrnky")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"V&loit",			"Vloit obsah schrnky")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"Od&stranit",			"Smazat oznaenou oblast")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,		"Vybr&at ve",			"Vybrat cel dokument")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Najt",			"Nalzt urit text")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"Nah&radit",			"Nahradit urit text jinm")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&Skok na",			"Pesun kurzoru na poadovanou stranu")
	
	MenuLabel(AP_MENU_ID_VIEW,			"&Zobrazit",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Nstroje",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standartn",			"Zobrazit nebo skrt standartn panel nstroj")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,		"&Formt",			"Zobrazit nebo skrt panel nstroj pro formtovn")
	MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,             "&Extra",                       "Zobrazit nebo skrt rozen panel nstroj")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Pravtko",			"Zobrazit nebo skrt pravtko")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,		"&Stavov dek",		"Zobrazit nebo skrt stavov dek")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"&Okraje",			"Zobrazovat okraje strnky")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Zhlav a zpat",		"Editovn textu v zhlav a zpat")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Lupa",			"Zmenen nebo zvten zobrazen dokumentu")

	MenuLabel(AP_MENU_ID_INSERT,			"&Vloit",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Zlom",			"Vloit zlom strnky nebo sloupce")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"s&la strnek",		"Vloit automatick slovn")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,		"Datum a as",			"Vloit as a/nebo datum")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Pole",			"Vloit potan pole")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Symbol",			"Vloit symbol nebo jin speciln znak")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"&Obrzek",			"Vloit obrzek ze souboru")

	MenuLabel(AP_MENU_ID_FORMAT,			"F&ormt",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Font",			"Zmnit font vybranho textu")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Odstavec",			"Zmnit formt vybranho odstavce")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Odrky a slovn",		"Pidat nebo zmnit odrky a slovn vybranho odstavce")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Okraje a stnovn",		"Pidat okraje a stnovn vybranmu textu")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Sloupce",			"Zmnit poet sloupc")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"St&yl",			"Definovat nebo aplikovat styl na vybran")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabeltory",			"Nastaven tabeltor")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Tun",			"Nastaven tunho psma pro vybranou oblast")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kurzva",			"Nastaven kurzivy pro vybranou oblast")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Potren",			"Podtren psma ve vybran oblasti")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"P&od arou",			"Nastaven linky nad textem (zmna)")

	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"Pek&rtnut",			"Pekrtnut psma ve vybran oblasti")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,		"Ho&rn index",			"Pevede oznaenou st na horn index (zmna)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"Spo&dn index",		"Pevede oznaenou st na spodn index (zmna)")
        MenuLabel(AP_MENU_ID_TOOLS,			"&Nstroje",			NULL)
        MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Pravopis",			"Najde peklepy v dokumentu")
        MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,		"Poet &slov",			"Zjist poet slov v dokumentu")
        MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Monosti",			"Nastaven monost")

	MenuLabel(AP_MENU_ID_ALIGN,			"&Umstn",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Vlevo",			"Zarovnn odstavce vlevo")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Uprosted",			"Zarovnn odstavce uprosted")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"V&pravo",			"Zarovnn odstavce vpravo")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Do bloku",			"Zarovnn odstavce do bloku")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Okno",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nov Okno",			"Otevt nov okno")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Zdvihnut toho okna")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Vce oken",			"Zobrazit seznam vech oken")

	MenuLabel(AP_MENU_ID_HELP,			"Npo&vda",			NULL)
        MenuLabel(AP_MENU_ID_HELP_CONTENTS,             "&Obsah npovdy",		"Zobraz obsah npovdy")
        MenuLabel(AP_MENU_ID_HELP_INDEX,                "&Rejstk",			"Zobraz rejstk npovdy")
        MenuLabel(AP_MENU_ID_HELP_CHECKVER,             "Uka &verzi",			"Zobraz slo verze programu")
        MenuLabel(AP_MENU_ID_HELP_SEARCH,               "&Hledej v npovd",		"Hledej npovdu o...")
	MenuLabel(AP_MENU_ID_HELP_ABOUT,                "O &programu %s",               "Zobrazit informace o programu, slo verze a copyright")
        MenuLabel(AP_MENU_ID_HELP_ABOUTOS,              "O Open &Source",		"Zobraz informace o Open Source")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"Zmnit na tento navrhovan pravopis")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorovat ve", 		"Ignorovat vechny vskyty tohoto slova v dokumentu")
	MenuLabel(AP_MENU_ID_SPELL_ADD,		"&Pidat", 			"Pidat toto slovo do uivatelskho slovnku")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()
